#!/usr/bin/perl
use lib '.';
use BlueRoseChar;
use CGI;
use FileHandle;
use strict;

my $req = new CGI;
my $shortname = $req->param("shortname");
my $char;
if (defined($shortname) and (-e "$shortname.txt")) {
    $char = BlueRoseChar->getChar($shortname);
} else {
    $char = BlueRoseChar->new();
}
# If there are input parameters, read them into the character
if ($req->param() > 5) {
    foreach my $key ($req->param()) {
	my $value = join('',$req->param($key));
        $char->$key( $value );
    }
}

########################################################################
my $hiddenfields = "";
my %html_of_field;

foreach ($char->basestats()) {
    # 60 columns wide for History/Description, 40 for Feats/Equipment/etc.
    my $cols = (m/^(History|Description)/) ? 60 : 40;
    $html_of_field{$_} = $char->statfield($req,$_,-cols=>$cols);
}
foreach my $num (1 .. 3) {
    foreach my $fld (qw(Name AttackBonus DamageBonus Range)) {
	my $key = 'Weapon_'.$num.'_'.$fld;
	$html_of_field{$key} = $char->statfield($req,$key);
    }
}
### Expand the skill list to include all skills
$char->expandSkills();

### Create the HTML for the list of skills
foreach my $i (1 .. 28) {
    my $key = 'Skill_'.$i.'_Name';
    my $name = $char->$key();
    if ($name =~ m/^(Craft|Knowledge):\s*(.*)/) {
	### Do not use the CGI.pm methods to create these -- because 
	### we are splitting one parameter into two fields: one hidden
	### (the prefix) and one text (the specifier).
	$html_of_field{$key} = "$1: " . 
	    "<input type=\"hidden\" name=\"$key\" value=\"$1: \">" .
	    "<input type=\"text\" size=\"10\" name=\"$key\" value=\"$2\">";
    } else {
	$html_of_field{$key} = $name.$req->hidden(-name=>$key,-value=>$name);
    }
    $key = 'Skill_'.$i.'_Modifier';
    $html_of_field{$key} = $req->popup_menu(-name=>$key,-values=>[-10..10],
					    -default=>0);
    $key = 'Skill_'.$i.'_Known';
    $html_of_field{$key} = $req->checkbox(-name=>$key,
					  -checked=>$char->$key(),
					  -value=>1,-label=>'');
    $key = 'Skill_'.$i.'_Favored';
    $html_of_field{$key} = $req->checkbox(-name=>$key,
					  -checked=>$char->$key(),
					  -value=>1,-label=>'');
}

########################################################################

print $req->header();
print <<EndDocument;
<html> <head>
<title>Blue Rose Notes</title>
<style type="text/css">
<!--
table.standard {
    padding-right: 2px; padding-left: 2px;
    padding-bottom: 2px; padding-top: 2px;
    text-align: center; 
    font-weight: normal; font-size: 8pt;
    font-family:  Verdana, Arial, Helvetica, sans-serif;
}
-->
</style>
</head>

<body bgcolor="ivory" text="#000000" link="#999999" vlink="#999999" alink="#999999" marginwidth="0" leftmargin="0" marginheight="0" topmargin="0">
<table border="0" cellpadding="0" cellspacing="0">
<tr>
  <td align="left" bgcolor="#006699" valign="top">
    <img src="../img/border_left_thin.jpg" width="45" height="782">
  </td>
  <td width="15"> &nbsp; </td>
  <td align="left" valign="top">
<h1><font color="#006699">Blue Rose Character Editor</font></h1>

<form method="POST" action="display1.cgi">
$hiddenfields

<p align="right">
<!-- start of whole-page eight-column table -->
<table class="standard" border="1" cellspacing="0" cellpadding="2">
<tr valign="top">
  <td colspan="2" align="left">
    <b>Name:</b>
  </td>
  <td colspan="6" align="left">
    $html_of_field{'CharacterName'}
  </td>
</tr>
<tr valign="top">
  <td colspan="2" align="left">
    <b>Background:</b>
  </td>
  <td colspan="6" align="left">
    $html_of_field{'CharacterBackground'}
  </td>
</tr>
<tr valign="top">
  <td colspan="2" align="left">
    <b>Role:</b>
  </td>
  <td colspan="6" align="left">
    $html_of_field{'CharacterRole'}
  </td>
</tr>
<tr valign="top">
  <td colspan="2" align="left">
    <b>Level:</b>
  </td>
  <td colspan="6" align="left">
    $html_of_field{'CharacterLevel'}
  </td>
</tr>
<tr valign="top">
  <td align="left">
    <b>History:</b>
  </td>
  <td colspan="7" align="center">
    $html_of_field{'History'}
  </td>
</tr>
<tr valign="top">
  <td align="left">
    <b>Description:</b>
  </td>
  <td colspan="7" align="center">
    $html_of_field{'Description'}
  </td>
</tr>
<tr valign="top">
  <td colspan="2" rowspan="2" align="center"> 
    <!-- begin abilities subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="2">
    <tr>
      <th colspan="2" align="center"> Abilities </th>
    </tr>
    <tr>
      <td align="center"> Strength: </td>
      <td align="left"> $html_of_field{'Ability_Strength_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Dexterity: </td>
      <td align="left"> $html_of_field{'Ability_Dexterity_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Constitution: </td>
      <td align="left"> $html_of_field{'Ability_Constitution_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Intelligence: </td>
      <td align="left"> $html_of_field{'Ability_Intelligence_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Wisdom: </td>
      <td align="left"> $html_of_field{'Ability_Wisdom_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Charisma: </td>
      <td align="left"> $html_of_field{'Ability_Charisma_Value'} </td>
    </tr>
    </table>
    <!-- end abilities subtable -->
  </td>
  <td colspan="2" rowspan="2" align="center">
    <!-- begin combat stats subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="2">
    <tr>
      <th colspan="2" align="center"> Combat </th>
    </tr>
    <tr>
      <td align="center"> Initiative: </td>
      <td align="left"> $html_of_field{'Initiative'} </td>
    </tr>
    <tr>
      <td align="center"> Defense: </td>
      <td align="left"> $html_of_field{'Defense'} </td>
    </tr>
    <tr>
      <td align="center"> Base Attack Bonus: </td>
      <td align="left"> $html_of_field{'BaseAttackBonus'} </td>
    </tr>
    <tr>
      <td align="center"> Melee Attack Bonus: </td>
      <td align="left"> $html_of_field{'MeleeAttackBonus'} </td>
    </tr>
    <tr>
      <td align="center"> Ranged Attack Bonus: </td>
      <td align="left"> $html_of_field{'RangedAttackBonus'} </td>
    </tr>
    </table>
    <!-- end combat stats subtable -->
  </td>
  <td colspan="2" align="center">
    <!-- begin saving throws subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="2">
    <tr>
      <th colspan="2" align="center"> Saving Throws </th>
    </tr>
    <tr>
      <td align="center"> Toughness: </td>
      <td align="left"> $html_of_field{'SavingThrow_Toughness_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Fortitude: </td>
      <td align="left"> $html_of_field{'SavingThrow_Fortitude_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Reflex: </td>
      <td align="left"> $html_of_field{'SavingThrow_Reflex_Value'} </td>
    </tr>
    <tr>
      <td align="center"> Will: </td>
      <td align="left"> $html_of_field{'SavingThrow_Will_Value'} </td>
    </tr>
    </table>
    <!-- end saving throws subtable -->
  </td>
  <td colspan="2" align="center">
    <!-- begin other stats subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="2">
    <tr>
      <th colspan="2" align="center"> Other Stats </th>
    </tr>
    <tr>
      <td align="center"> Size: </td>
      <td align="left"> $html_of_field{'Size'} </td>
    </tr>
    <tr>
      <td align="center"> Speed: </td>
      <td align="left"> $html_of_field{'Speed'} </td>
    </tr>
    </table>
    <!-- end other stats subtable -->
  </td>
</tr>
<tr valign="top">
  <td colspan="4" rowspan="2" align="center"> 
    <!-- begin characteristics subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="2">
    <tr>
      <th colspan="2"> Characteristics </th>
    </tr>
    <tr>
      <td align="center"> Conviction: </td>
      <td align="left"> $html_of_field{'Conviction'} </td>
    </tr>
    <tr>
      <td align="center"> Corruption: </td>
      <td align="left"> $html_of_field{'Corruption'} </td>
    </tr>
    <tr>
      <td align="center"> Alignment: </td>
      <td align="left"> $html_of_field{'Alignment'} </td>
    </tr>
    <tr>
      <td align="center"> Calling: </td>
      <td align="left"> $html_of_field{'Calling'} </td>
    </tr>
    <tr>
      <td align="center"> Light Nature: </td>
      <td align="left"> $html_of_field{'LightNature'} </td>
    </tr>
    <tr>
      <td align="center"> Shadow Nature: </td>
      <td align="left"> $html_of_field{'ShadowNature'} </td>
    </tr>
    </table>
    <!-- end characteristics subtable -->
  </td>
</tr>
<tr valign="top">
  <td colspan="4" align="center"> 
    <!-- begin wealth/reputation subtable -->
    <table class="standard" border="0" cellpadding="0" cellspacing="2">
    <tr>
      <th colspan="2" align="center"> Wealth &amp; Reputation </th>
    </tr>
    <tr>
      <td align="center"> Wealth: </td>
      <td align="left"> $html_of_field{'Wealth'} </td>
    </tr>
    <tr>
      <td align="center"> Profession: </td>
      <td align="left"> $html_of_field{'Profession'} </td>
    </tr>
    <tr>
      <td align="center"> Reputation: </td>
      <td align="left"> $html_of_field{'Reputation'} </td>
    </tr>
    </table>
    <!-- end wealth/reputation subtable -->
  </td>
</tr>
<tr>
  <th colspan="8" align="center"> <big>Weapons</big> </th>
</tr>
<tr>
  <th colspan="2" align="center"> Name </th>
  <th colspan="2" align="center"> Attack Bonus </th>
  <th colspan="2" align="center"> Damage Bonus </th>
  <th colspan="2" align="center"> Range </th>
</tr>
<tr>
  <td colspan="2" align="center"> $html_of_field{'Weapon_1_Name'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_1_AttackBonus'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_1_DamageBonus'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_1_Range'} </td>
</tr>
<tr>
  <td colspan="2" align="center"> $html_of_field{'Weapon_2_Name'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_2_AttackBonus'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_2_DamageBonus'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_2_Range'} </td>
</tr>
<tr>
  <td colspan="2" align="center"> $html_of_field{'Weapon_3_Name'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_3_AttackBonus'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_3_DamageBonus'} </td>
  <td colspan="2" align="center"> $html_of_field{'Weapon_3_Range'} </td>
</tr>
<tr>
  <th colspan="8" align="center"> <big>Skills</big> (Modifiers/Known/Favored) </th>
</tr>
<!-- begin skill list -->
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_1_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_1_Modifier'}
    $html_of_field{'Skill_1_Known'}
    $html_of_field{'Skill_1_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_8_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_8_Modifier'}
    $html_of_field{'Skill_8_Known'}
    $html_of_field{'Skill_8_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_15_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_15_Modifier'}
    $html_of_field{'Skill_15_Known'}
    $html_of_field{'Skill_15_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_22_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_22_Modifier'}
    $html_of_field{'Skill_22_Known'}
    $html_of_field{'Skill_22_Favored'}
  </td>
</tr>
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_2_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_2_Modifier'}
    $html_of_field{'Skill_2_Known'}
    $html_of_field{'Skill_2_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_9_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_9_Modifier'}
    $html_of_field{'Skill_9_Known'}
    $html_of_field{'Skill_9_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_16_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_16_Modifier'}
    $html_of_field{'Skill_16_Known'}
    $html_of_field{'Skill_16_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_23_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_23_Modifier'}
    $html_of_field{'Skill_23_Known'}
    $html_of_field{'Skill_23_Favored'}
  </td>
</tr>
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_3_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_3_Modifier'}
    $html_of_field{'Skill_3_Known'}
    $html_of_field{'Skill_3_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_10_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_10_Modifier'}
    $html_of_field{'Skill_10_Known'}
    $html_of_field{'Skill_10_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_17_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_17_Modifier'}
    $html_of_field{'Skill_17_Known'}
    $html_of_field{'Skill_17_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_24_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_24_Modifier'}
    $html_of_field{'Skill_24_Known'}
    $html_of_field{'Skill_24_Favored'}
  </td>
</tr>
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_4_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_4_Modifier'}
    $html_of_field{'Skill_4_Known'}
    $html_of_field{'Skill_4_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_11_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_11_Modifier'}
    $html_of_field{'Skill_11_Known'}
    $html_of_field{'Skill_11_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_18_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_18_Modifier'}
    $html_of_field{'Skill_18_Known'}
    $html_of_field{'Skill_18_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_25_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_25_Modifier'}
    $html_of_field{'Skill_25_Known'}
    $html_of_field{'Skill_25_Favored'}
  </td>
</tr>
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_5_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_5_Modifier'}
    $html_of_field{'Skill_5_Known'}
    $html_of_field{'Skill_5_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_12_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_12_Modifier'}
    $html_of_field{'Skill_12_Known'}
    $html_of_field{'Skill_12_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_19_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_19_Modifier'}
    $html_of_field{'Skill_19_Known'}
    $html_of_field{'Skill_19_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_26_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_26_Modifier'}
    $html_of_field{'Skill_26_Known'}
    $html_of_field{'Skill_26_Favored'}
  </td>
</tr>
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_6_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_6_Modifier'}
    $html_of_field{'Skill_6_Known'}
    $html_of_field{'Skill_6_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_13_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_13_Modifier'}
    $html_of_field{'Skill_13_Known'}
    $html_of_field{'Skill_13_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_20_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_20_Modifier'}
    $html_of_field{'Skill_20_Known'}
    $html_of_field{'Skill_20_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_27_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_27_Modifier'}
    $html_of_field{'Skill_27_Known'}
    $html_of_field{'Skill_27_Favored'}
  </td>
</tr>
<tr>
  <td align="left" nowrap>
    $html_of_field{'Skill_7_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_7_Modifier'}
    $html_of_field{'Skill_7_Known'}
    $html_of_field{'Skill_7_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_14_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_14_Modifier'}
    $html_of_field{'Skill_14_Known'}
    $html_of_field{'Skill_14_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_21_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_21_Modifier'}
    $html_of_field{'Skill_21_Known'}
    $html_of_field{'Skill_21_Favored'}
  </td>
  <td align="left" nowrap>
    $html_of_field{'Skill_28_Name'}
  </td>
  <td align="center" nowrap>
    $html_of_field{'Skill_28_Modifier'}
    $html_of_field{'Skill_28_Known'}
    $html_of_field{'Skill_28_Favored'}
  </td>
</tr>
<!-- end skill list -->
<tr>
  <th colspan="4" align="center"> <big>Arcana</big> </th>
  <th colspan="4" align="center"> <big>Feats</big> </th>
</tr>
<tr>
  <td colspan="4" align="center">
$html_of_field{'Arcana'}
  </td>
  <td colspan="4" align="center">
$html_of_field{'Feats'}
  </td>
</tr>
<tr>
  <th colspan="4" align="center"> <big>Special Abilities</big> </th>
  <th colspan="4" align="center"> <big>Equipment</big> </th>
</tr>
<tr>
  <td colspan="4" align="center">
$html_of_field{'SpecialAbilities'}
  </td>
  <td colspan="4" align="center">
$html_of_field{'Equipment'}
  </td>
</tr>
<tr>
  <td colspan="8" align="center">
    <select name="style">
      <option selected="1" value="default">Default Style</option>
      <option value="xml">XMl Style</option>
    </select>
    <input type="submit" value="Submit">
  </td>
</tr>
</table>

</p>
</form>

<p>&nbsp;</p>

<hr>
<address>John H. Kim &lt;jhkim\@darkshire.net&gt;</address>
<!-- hhmts start -->
Last modified: Mon Apr 25 21:41:27 2005
<!-- hhmts end -->
</td>
</tr>
</table>
</body> </html>
EndDocument

########################################################################
